# UI/UX Feedback

**ID:** Feedback-20260302-144742
**URL:** http://127.0.0.1:5858/
**Date:** 2026-03-02 14:53:29

## Selected Elements

- `{'selector': 'div.deliverable-card:nth-of-type(1)', 'parents': ['div.workflow-panel.expanded', 'div.workflow-panel-body', 'div.deliverables-area', 'div.deliverables-grid']}`

## Feedback

lets do follwing changes, 1. the markdown preview in the modal window that directly open from file in deliverables should be the same as the markdown preview  opened from the folder in deliverables, please reuse the same preview function. 2. for different stage, let's have a section and subtitle for them, and all the related deliverables should be listed into different stage accordingly

## Screenshot

![Screenshot](x-ipe-docs/uiux-feedback/Feedback-20260302-144742/page-screenshot.png)
